#
# spec file for package perl-experimental
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-experimental
Version:        0.019
Release:        lp152.3.2
%define cpan_name experimental
Summary:        Experimental features made easy
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/experimental/
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEONT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.89
BuildRequires:  perl(version)
Requires:       perl(version)
%{perl_requires}

%description
This pragma provides an easy and convenient way to enable or disable
experimental features.

Every version of perl has some number of features present but considered
"experimental." For much of the life of Perl 5, this was only a designation
found in the documentation. Starting in Perl v5.10.0, and more aggressively
in v5.18.0, experimental features were placed behind pragmata used to
enable the feature and disable associated warnings.

The 'experimental' pragma exists to combine the required incantations into
a single interface stable across releases of perl. For every experimental
feature, this should enable the feature and silence warnings for the
enclosing lexical scope:

  use experimental 'feature-name';

To disable the feature and, if applicable, re-enable any warnings, use:

  no experimental 'feature-name';

The supported features, documented further below, are:

* * 'array_base' - allow the use of '$[' to change the starting index of
  '@array'.

This is supported on all versions of perl.

* * 'autoderef' - allow push, each, keys, and other built-ins on
  references.

This was added in perl 5.14.0 and removed in perl 5.23.1.

* * 'bitwise' - allow the new stringwise bit operators

This was added in perl 5.22.0.

* * 'const_attr' - allow the :const attribute on subs

This was added in perl 5.22.0.

* * 'lexical_topic' - allow the use of lexical '$_' via 'my $_'.

This was added in perl 5.10.0 and removed in perl 5.23.4.

* * 'lexical_subs' - allow the use of lexical subroutines.

This was added in 5.18.0.

* * 'postderef' - allow the use of postfix dereferencing expressions,
  including in interpolating strings

This was added in perl 5.20.0.

* * 're_strict' - enables strict mode in regular expressions

This was added in perl 5.22.0.

* * 'refaliasing' - allow aliasing via '\$x = \$y'

This was added in perl 5.22.0.

* * 'regex_sets' - allow extended bracketed character classes in regexps

This was added in perl 5.18.0.

* * 'signatures' - allow subroutine signatures (for named arguments)

This was added in perl 5.20.0.

* * 'smartmatch' - allow the use of '~~'

This was added in perl 5.10.0, but it should be noted there are significant
incompatibilities between 5.10.0 and 5.10.1.

* * 'switch' - allow the use of '~~', given, and when

This was added in perl 5.10.0.

* * 'win32_perlio' - allows the use of the :win32 IO layer.

This was added on perl 5.22.0.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Fri Dec  8 2017 coolo@suse.com
- updated to 0.019
  see /usr/share/doc/packages/perl-experimental/Changes
  0.019     2017-12-03 18:40:19+01:00 Europe/Amsterdam
  - Rerelease without NYTProf files
  0.018     2017-11-29 12:39:58+01:00 Europe/Amsterdam
  - Make test pass when warnings are enabled
  - Make experimental installable on 5.8
* Wed Nov 15 2017 coolo@suse.com
- updated to 0.017
  see /usr/share/doc/packages/perl-experimental/Changes
  0.017     2017-11-14 16:23:53+01:00 Europe/Amsterdam
    Remove auto_deref for 5.24+
* Sun Oct 11 2015 coolo@suse.com
- updated to 0.016
  see /usr/share/doc/packages/perl-experimental/Changes
  0.016     2015-10-10 12:46:48+02:00 Europe/Amsterdam
    Fix deprecation check
* Sun Oct  4 2015 coolo@suse.com
- updated to 0.015
  see /usr/share/doc/packages/perl-experimental/Changes
  0.015     2015-10-03 14:21:18+02:00 Europe/Amsterdam
    Make lexical_topic a deprecated feature
* Mon Sep 14 2015 coolo@suse.com
- updated to 0.014
  see /usr/share/doc/packages/perl-experimental/Changes
  0.014     2015-09-12 00:29:37+02:00 Europe/Amsterdam
    Add bitwise to list of known features
* Mon Oct 27 2014 ncutler@suse.com
- updated to 0.013
* Mon Oct 27 2014 ncutler@suse.com
  Upstream changes
- 0.013 Rename lvalue_refs to refaliasing
* Mon Oct 13 2014 ncutler@suse.com
  Upstream changes
- 0.012 Added lvalue references feature
* Mon Sep 29 2014 ncutler@suse.com
  Upstream changes
- 0.011 Clarified which order to apply pragmas [Grant McLean]
- 0.010 Add returning 1's to evals in tests
- 0.009 Hardcode features for perl < 5.15.7
* Thu Aug  7 2014 ncutler@suse.com
- initial package 0.008
  * created by cpanspec 1.78.08
- checked license
- took over maintainership
